@@ -3,9 +3,9 @@ from os import path
 from subprocess import check_output, run, CalledProcessError
 
 VFLOW_PATHS = {'bundle':'/',
-               'operators':'/files/vflow/subengines/com/sap/python36/operators/',
-               'pipelines':'/files/vflow/graphs/',
-               'dockerfiles':'/files/vflow/dockerfiles/'}
+               'operators':'/files/vflow/subengines/com/sap/python36/',
+               'graphs':'/files/vflow/',
+               'dockerfiles':'/files/vflow/'}
 
 def get_dir_files(dir) :
     logging.info(f'List file in folder: {dir}')
@@ -86,5 +86,5 @@ def solution_to_repo(source, solution_name, version, description) :
         cmd = ['vctl','vrep','user','export-solution',solution_name,version,source,'-s',description]
     else :
         cmd = ['vctl','vrep','user','export-solution',solution_name,version,source]
-    logging.info(f'Export vrep  \'{source}\'  to solution: {solution_name}-{version} ( ({" ".join(cmd)}))')
+    logging.info(f'Export vrep  \'{source}\'  to solution: {solution_name}-{version} ({" ".join(cmd)})')
     run(cmd)
\ No newline at end of file
